@@ -11,6 +11,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"go.k6.io/k6/execution"
+	"go.k6.io/k6/execution/local"
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/lib/testutils"
 	"go.k6.io/k6/lib/testutils/minirunner"
@@ -41,7 +42,7 @@ func getTestRunState(tb testing.TB, options lib.Options, runner lib.Runner) *lib
 }
 
 func getControlSurface(tb testing.TB, testState *lib.TestRunState) *ControlSurface {
-	execScheduler, err := execution.NewScheduler(testState)
+	execScheduler, err := execution.NewScheduler(testState, local.NewController())
 	require.NoError(tb, err)
 
 	me, err := engine.NewMetricsEngine(testState.Registry, testState.Logger)
@@ -61,6 +62,8 @@ func getControlSurface(tb testing.TB, testState *lib.TestRunState) *ControlSurfa
 }
 
 func TestGetGroups(t *testing.T) {
+	t.Parallel()
+
 	g0, err := lib.NewGroup("", nil)
 	assert.NoError(t, err)
 	g1, err := g0.Group("group 1")
@@ -71,14 +74,21 @@ func TestGetGroups(t *testing.T) {
 	cs := getControlSurface(t, getTestRunState(t, lib.Options{}, &minirunner.MiniRunner{Group: g0}))
 
 	t.Run("list", func(t *testing.T) {
+		t.Parallel()
+
 		rw := httptest.NewRecorder()
 		NewHandler(cs).ServeHTTP(rw, httptest.NewRequest(http.MethodGet, "/v1/groups", nil))
 		res := rw.Result()
+		t.Cleanup(func() {
+			assert.NoError(t, res.Body.Close())
+		})
 		body := rw.Body.Bytes()
 		assert.Equal(t, http.StatusOK, res.StatusCode)
 		assert.NotEmpty(t, body)
 
 		t.Run("document", func(t *testing.T) {
+			t.Parallel()
+
 			var doc groupsJSONAPI
 			assert.NoError(t, json.Unmarshal(body, &doc))
 			if assert.NotEmpty(t, doc.Data) {
@@ -87,6 +97,8 @@ func TestGetGroups(t *testing.T) {
 		})
 
 		t.Run("groups", func(t *testing.T) {
+			t.Parallel()
+
 			var envelop groupsJSONAPI
 			require.NoError(t, json.Unmarshal(body, &envelop))
 			require.Len(t, envelop.Data, 3)
@@ -118,10 +130,15 @@ func TestGetGroups(t *testing.T) {
 		})
 	})
 	for _, gp := range []*lib.Group{g0, g1, g2} {
+		gp := gp
 		t.Run(gp.Name, func(t *testing.T) {
+			t.Parallel()
 			rw := httptest.NewRecorder()
 			NewHandler(cs).ServeHTTP(rw, httptest.NewRequest(http.MethodGet, "/v1/groups/"+gp.ID, nil))
 			res := rw.Result()
+			t.Cleanup(func() {
+				assert.NoError(t, res.Body.Close())
+			})
 			assert.Equal(t, http.StatusOK, res.StatusCode)
 		})
 	}
