@@ -1,7 +1,6 @@
 package cmd
 
 import (
-	"bytes"
 	"context"
 	"encoding/json"
 	"errors"
@@ -106,33 +105,24 @@ func (c *cmdCloud) run(cmd *cobra.Command, args []string) error {
 	modifyAndPrintBar(c.gs, progressBar, pb.WithConstProgress(0, "Building the archive..."))
 	arc := testRunState.Runner.MakeArchive()
 
-	// TODO: Fix this
-	// We reuse cloud.Config for parsing options.ext.loadimpact, but this probably shouldn't be
-	// done, as the idea of options.ext is that they are extensible without touching k6. But in
-	// order for this to happen, we shouldn't actually marshall cloud.Config on top of it, because
-	// it will be missing some fields that aren't actually mentioned in the struct.
-	// So in order for use to copy the fields that we need for loadimpact's api we unmarshal in
-	// map[string]interface{} and copy what we need if it isn't set already
-	var tmpCloudConfig map[string]interface{}
-	if val, ok := arc.Options.External["loadimpact"]; ok {
-		dec := json.NewDecoder(bytes.NewReader(val))
-		dec.UseNumber() // otherwise float64 are used
-		if err = dec.Decode(&tmpCloudConfig); err != nil {
-			return err
-		}
+	tmpCloudConfig, err := cloudapi.GetTemporaryCloudConfig(arc.Options.Cloud, arc.Options.External)
+	if err != nil {
+		return err
 	}
 
 	// Cloud config
-	cloudConfig, err := cloudapi.GetConsolidatedConfig(
-		test.derivedConfig.Collectors["cloud"], c.gs.Env, "", arc.Options.External)
+	cloudConfig, warn, err := cloudapi.GetConsolidatedConfig(
+		test.derivedConfig.Collectors["cloud"], c.gs.Env, "", arc.Options.Cloud, arc.Options.External)
 	if err != nil {
 		return err
 	}
 	if !cloudConfig.Token.Valid {
 		return errors.New("Not logged in, please use `k6 login cloud`.") //nolint:golint,revive,stylecheck
 	}
-	if tmpCloudConfig == nil {
-		tmpCloudConfig = make(map[string]interface{}, 3)
+
+	// Display config warning if needed
+	if warn != "" {
+		modifyAndPrintBar(c.gs, progressBar, pb.WithConstProgress(0, "Warning: "+warn))
 	}
 
 	if cloudConfig.Token.Valid {
@@ -148,11 +138,15 @@ func (c *cmdCloud) run(cmd *cobra.Command, args []string) error {
 	if arc.Options.External == nil {
 		arc.Options.External = make(map[string]json.RawMessage)
 	}
-	arc.Options.External["loadimpact"], err = json.Marshal(tmpCloudConfig)
+
+	b, err := json.Marshal(tmpCloudConfig)
 	if err != nil {
 		return err
 	}
 
+	arc.Options.Cloud = b
+	arc.Options.External[cloudapi.LegacyCloudConfigKey] = b
+
 	name := cloudConfig.Name.String
 	if !cloudConfig.Name.Valid || cloudConfig.Name.String == "" {
 		name = filepath.Base(test.sourceRootPath)
