@@ -1,15 +1,12 @@
 package cmd
 
 import (
-	"bytes"
 	"context"
-	"encoding/json"
 	"errors"
 	"fmt"
 	"io"
 	"net/http"
 	"os"
-	"runtime"
 	"strings"
 	"sync"
 	"syscall"
@@ -25,9 +22,9 @@ import (
 	"go.k6.io/k6/errext/exitcodes"
 	"go.k6.io/k6/event"
 	"go.k6.io/k6/execution"
+	"go.k6.io/k6/execution/local"
 	"go.k6.io/k6/js/common"
 	"go.k6.io/k6/lib"
-	"go.k6.io/k6/lib/consts"
 	"go.k6.io/k6/lib/fsext"
 	"go.k6.io/k6/lib/trace"
 	"go.k6.io/k6/metrics"
@@ -39,6 +36,9 @@ import (
 // cmdRun handles the `k6 run` sub-command
 type cmdRun struct {
 	gs *state.GlobalState
+
+	// TODO: figure out something more elegant?
+	loadConfiguredTest func(cmd *cobra.Command, args []string) (*loadedAndConfiguredTest, execution.Controller, error)
 }
 
 const (
@@ -100,7 +100,7 @@ func (c *cmdRun) run(cmd *cobra.Command, args []string) (err error) {
 		c.gs.Events.UnsubscribeAll()
 	}()
 
-	test, err := loadAndConfigureTest(c.gs, cmd, args, getConfig)
+	test, controller, err := c.loadConfiguredTest(cmd, args)
 	if err != nil {
 		return err
 	}
@@ -132,7 +132,7 @@ func (c *cmdRun) run(cmd *cobra.Command, args []string) (err error) {
 
 	// Create a local execution scheduler wrapping the runner.
 	logger.Debug("Initializing the execution scheduler...")
-	execScheduler, err := execution.NewScheduler(testRunState)
+	execScheduler, err := execution.NewScheduler(testRunState, controller)
 	if err != nil {
 		return err
 	}
@@ -406,7 +406,8 @@ func (c *cmdRun) run(cmd *cobra.Command, args []string) (err error) {
 			reportCtx, reportCancel := context.WithTimeout(globalCtx, 3*time.Second)
 			defer reportCancel()
 			logger.Debug("Sending usage report...")
-			if rerr := reportUsage(reportCtx, execScheduler); rerr != nil {
+
+			if rerr := reportUsage(reportCtx, execScheduler, test); rerr != nil {
 				logger.WithError(rerr).Debug("Error sending usage report")
 			} else {
 				logger.Debug("Usage report sent successfully")
@@ -459,6 +460,10 @@ func (c *cmdRun) setupTracerProvider(ctx context.Context, test *loadedAndConfigu
 func getCmdRun(gs *state.GlobalState) *cobra.Command {
 	c := &cmdRun{
 		gs: gs,
+		loadConfiguredTest: func(cmd *cobra.Command, args []string) (*loadedAndConfiguredTest, execution.Controller, error) {
+			test, err := loadAndConfigureLocalTest(gs, cmd, args, getConfig)
+			return test, local.NewController(), err
+		},
 	}
 
 	exampleText := getExampleText(gs, `
@@ -498,39 +503,6 @@ a commandline interface for interacting with it.`,
 	return runCmd
 }
 
-func reportUsage(ctx context.Context, execScheduler *execution.Scheduler) error {
-	execState := execScheduler.GetState()
-	executorConfigs := execScheduler.GetExecutorConfigs()
-
-	executors := make(map[string]int)
-	for _, ec := range executorConfigs {
-		executors[ec.GetType()]++
-	}
-
-	body, err := json.Marshal(map[string]interface{}{
-		"k6_version": consts.Version,
-		"executors":  executors,
-		"vus_max":    execState.GetInitializedVUsCount(),
-		"iterations": execState.GetFullIterationCount(),
-		"duration":   execState.GetCurrentTestRunDuration().String(),
-		"goos":       runtime.GOOS,
-		"goarch":     runtime.GOARCH,
-	})
-	if err != nil {
-		return err
-	}
-	req, err := http.NewRequestWithContext(ctx, http.MethodPost, "https://reports.k6.io/", bytes.NewBuffer(body))
-	if err != nil {
-		return err
-	}
-	req.Header.Set("Content-Type", "application/json")
-	res, err := http.DefaultClient.Do(req)
-	if err == nil {
-		_ = res.Body.Close()
-	}
-	return err
-}
-
 func handleSummaryResult(fs fsext.Fs, stdOut, stdErr io.Writer, result map[string]io.Reader) error {
 	var errs []error
 
