@@ -4,7 +4,6 @@ package grpc
 import (
 	"errors"
 	"fmt"
-	"sync"
 
 	"github.com/dop251/goja"
 	"github.com/mstoykov/k6-taskqueue-lib/taskqueue"
@@ -16,9 +15,7 @@ import (
 type (
 	// RootModule is the global module instance that will create module
 	// instances for each VU.
-	RootModule struct {
-		warnAboutExperimental *sync.Once
-	}
+	RootModule struct{}
 
 	// ModuleInstance represents an instance of the GRPC module for every VU.
 	ModuleInstance struct {
@@ -38,13 +35,6 @@ func New() *RootModule {
 	return &RootModule{}
 }
 
-// NewExperimental returns a pointer to a new RootModule instance.
-func NewExperimental() *RootModule {
-	return &RootModule{
-		warnAboutExperimental: &sync.Once{},
-	}
-}
-
 // NewModuleInstance implements the modules.Module interface to return
 // a new instance for each VU.
 func (r *RootModule) NewModuleInstance(vu modules.VU) modules.Instance {
@@ -53,15 +43,6 @@ func (r *RootModule) NewModuleInstance(vu modules.VU) modules.Instance {
 		common.Throw(vu.Runtime(), fmt.Errorf("failed to register GRPC module metrics: %w", err))
 	}
 
-	if r.warnAboutExperimental != nil {
-		r.warnAboutExperimental.Do(func() {
-			vu.InitEnv().Logger.Warn(
-				"k6/experimental/grpc is now part of the k6 core, please change your imports to use k6/net/grpc instead." +
-					" The k6/experimental/grpc will be removed in k6 v0.51.0",
-			)
-		})
-	}
-
 	mi := &ModuleInstance{
 		vu:      vu,
 		exports: make(map[string]interface{}),
