@@ -1,3 +1,4 @@
+// Package main - this package generates some of the code for k6/html
 package main
 
 import (
@@ -58,8 +59,7 @@ const (
 //nolint:lll,gochecknoglobals
 var (
 	// Default return values for urlTemplate functions. Either an empty string or the current URL.
-	defaultURLEmpty   = []templateArg{"\"\""}
-	defaultURLCurrent = []templateArg{"e.sel.URL"}
+	defaultURLEmpty = []templateArg{"\"\""}
 
 	// Common default return values for intTemplates
 	defaultInt0      = []templateArg{"0"}
@@ -132,7 +132,7 @@ var funcDefs = []struct {
 	{"MediaElement", "CurrentSrc", "src", stringTemplate, nil},
 	{"MediaElement", "DefaultMuted", "muted", boolTemplate, nil},
 	{"MediaElement", "MediaGroup", "mediagroup", stringTemplate, nil},
-	{"BaseElement", "Href", "href", urlTemplate, defaultURLCurrent},
+	{"BaseElement", "Href", "href", urlTemplate, []templateArg{"b.sel.URL"}},
 	{"BaseElement", "Target", "target", stringTemplate, nil},
 	{"ButtonElement", "AccessKey", "accesskey", stringTemplate, nil},
 	{"ButtonElement", "Autofocus", "autofocus", boolTemplate, nil},
@@ -365,8 +365,9 @@ func main() {
 
 //nolint:gochecknoglobals
 var elemFuncsTemplate = template.Must(template.New("").Funcs(template.FuncMap{
-	"buildStruct": buildStruct,
-	"returnType":  returnType,
+	"buildStruct":  buildStruct,
+	"returnType":   returnType,
+	"receiverName": receiverName,
 }).Parse(`// generated by js/modules/k6/html/gen/gen_elements.go;  DO NOT EDIT
 package html
 
@@ -392,11 +393,11 @@ func selToElement(sel Selection) goja.Value {
 {{ $templateTypes := .TemplateTypes }}
 {{ range $funcDef := .FuncDefs -}}
 
-func (e {{$funcDef.Elem}}) {{$funcDef.Method}}() {{ returnType $funcDef.TemplateType }} {
+func ({{ receiverName $funcDef.Elem }} {{$funcDef.Elem}}) {{$funcDef.Method}}() {{ returnType $funcDef.TemplateType }} {
 {{- if eq $funcDef.TemplateType $templateTypes.Int }}
-	return e.attrAsInt("{{ $funcDef.Attr }}", {{ index $funcDef.TemplateArgs 0 }})
+	return {{ receiverName $funcDef.Elem }}.attrAsInt("{{ $funcDef.Attr }}", {{ index $funcDef.TemplateArgs 0 }})
 {{- else if eq $funcDef.TemplateType $templateTypes.Enum }}
-	attrVal := e.attrAsString("{{ $funcDef.Attr }}")
+	attrVal := {{ receiverName $funcDef.Elem }}.attrAsString("{{ $funcDef.Attr }}")
 	switch attrVal {
 	{{- range $optIdx, $optVal := $funcDef.TemplateArgs }}
 	{{- if ne $optIdx 0 }}
@@ -408,14 +409,14 @@ func (e {{$funcDef.Elem}}) {{$funcDef.Method}}() {{ returnType $funcDef.Template
 		return "{{ index $funcDef.TemplateArgs 0 }}"
 	}
 {{- else if eq $funcDef.TemplateType $templateTypes.GojaEnum }}
-	attrVal, exists := e.sel.sel.Attr("{{ $funcDef.Attr }}")
+	attrVal, exists := {{ receiverName $funcDef.Elem }}.sel.sel.Attr("{{ $funcDef.Attr }}")
 	if !exists {
 		return goja.Undefined()
 	}
 	switch attrVal {
 	{{- range $optVal := $funcDef.TemplateArgs }}
 	case "{{$optVal}}":
-		return e.sel.rt.ToValue(attrVal)
+		return {{ receiverName $funcDef.Elem }}.sel.rt.ToValue(attrVal)
 	{{- end}}
 	default:
 		return goja.Undefined()
@@ -423,11 +424,11 @@ func (e {{$funcDef.Elem}}) {{$funcDef.Method}}() {{ returnType $funcDef.Template
 {{- else if eq $funcDef.TemplateType $templateTypes.Const }}
 	return "{{ index $funcDef.TemplateArgs 0 }}"
 {{- else if eq $funcDef.TemplateType $templateTypes.URL }}
-	return e.attrAsURLString("{{ $funcDef.Attr }}", {{ index $funcDef.TemplateArgs 0 }})
+	return {{ receiverName $funcDef.Elem }}.attrAsURLString("{{ $funcDef.Attr }}", {{ index $funcDef.TemplateArgs 0 }})
 {{- else if eq $funcDef.TemplateType $templateTypes.String }}
-	return e.attrAsString("{{ $funcDef.Attr }}")
+	return {{ receiverName $funcDef.Elem }}.attrAsString("{{ $funcDef.Attr }}")
 {{- else if eq $funcDef.TemplateType $templateTypes.Bool }}
-	return e.attrIsPresent("{{ $funcDef.Attr }}")
+	return {{ receiverName $funcDef.Elem }}.attrIsPresent("{{ $funcDef.Attr }}")
 {{- end}}
 }
 {{ end }}
@@ -456,6 +457,11 @@ func returnType(tt templateType) string {
 	}
 }
 
+// return the name of the receiver given the name of the type
+func receiverName(t string) string {
+	return strings.ToLower(t[:1])
+}
+
 // Default node handler functions for ast.Inspect. Return itself unless it's found a "const" or "struct" keyword
 func (ce *astInspectState) defaultHandler(node ast.Node) nodeHandlerFunc {
 	ce.elemName = ""
