@@ -299,6 +299,7 @@ func (s Selection) Attr(name string, def ...goja.Value) goja.Value {
 	return s.rt.ToValue(val)
 }
 
+//nolint:revive,stylecheck // var-naming wants this to be HTML but this will break the API
 func (s Selection) Html() goja.Value {
 	val, err := s.sel.Html()
 	if err != nil {
@@ -337,7 +338,7 @@ func (s Selection) Val() goja.Value {
 	case SelectTagName:
 		selected := s.sel.First().Find("option[selected]")
 		if _, exists := s.sel.Attr("multiple"); exists {
-			return s.rt.ToValue(selected.Map(func(idx int, opt *goquery.Selection) string { return valueOrHTML(opt) }))
+			return s.rt.ToValue(selected.Map(func(_ int, opt *goquery.Selection) string { return valueOrHTML(opt) }))
 		}
 
 		return s.rt.ToValue(valueOrHTML(selected))
@@ -361,7 +362,7 @@ func (s Selection) Each(v goja.Value) Selection {
 		common.Throw(s.rt, errors.New("the argument to each() must be a function"))
 	}
 
-	fn := func(idx int, sel *goquery.Selection) {
+	fn := func(idx int, _ *goquery.Selection) {
 		if _, err := gojaFn(v, s.rt.ToValue(idx), selToElement(Selection{s.rt, s.sel.Eq(idx), s.URL})); err != nil {
 			common.Throw(s.rt, fmt.Errorf("the function passed to each() failed: %w", err))
 		}
@@ -480,6 +481,9 @@ func (s Selection) Index(def ...goja.Value) int {
 	}
 }
 
+// Data return the value at the named data store for the first element in the set of matched elements.
+// Mimics jquery.data
+//
 // When 0 arguments: Read all data from attributes beginning with "data-".
 // When 1 argument: Append argument to "data-" then find for a matching attribute
 func (s Selection) Data(def ...string) goja.Value {
