@@ -1,7 +1,7 @@
 package lib
 
 import (
-	"crypto/md5"
+	"crypto/md5" //nolint:gosec
 	"encoding/hex"
 	"encoding/json"
 	"errors"
@@ -15,10 +15,10 @@ import (
 	"go.k6.io/k6/lib/types"
 )
 
-// Separator for group IDs.
+// GroupSeparator for group IDs.
 const GroupSeparator = "::"
 
-// Error emitted if you attempt to instantiate a Group or Check that contains the separator.
+// ErrNameContainsGroupSeparator is emitted if you attempt to instantiate a Group or Check that contains the separator.
 var ErrNameContainsGroupSeparator = errors.New("group and check names may not contain '::'")
 
 // StageFields defines the fields used for a Stage; this is a dumb hack to make the JSON code
@@ -34,7 +34,8 @@ type StageFields struct {
 // A Stage defines a step in a test's timeline.
 type Stage StageFields
 
-// For some reason, implementing UnmarshalText makes encoding/json treat the type as a string.
+// UnmarshalJSON implements the json.Unmarshaler interface
+// for some reason, implementing UnmarshalText makes encoding/json treat the type as a string.
 func (s *Stage) UnmarshalJSON(b []byte) error {
 	var fields StageFields
 	if err := json.Unmarshal(b, &fields); err != nil {
@@ -44,10 +45,12 @@ func (s *Stage) UnmarshalJSON(b []byte) error {
 	return nil
 }
 
+// MarshalJSON implements the json.Marshaler interface
 func (s Stage) MarshalJSON() ([]byte, error) {
 	return json.Marshal(StageFields(s))
 }
 
+// UnmarshalText implements the encoding.TextUnmarshaler interface
 func (s *Stage) UnmarshalText(b []byte) error {
 	var stage Stage
 	parts := strings.SplitN(string(b), ":", 2)
@@ -99,7 +102,7 @@ type Group struct {
 	checkMutex sync.Mutex
 }
 
-// Creates a new group with the given name and parent group.
+// NewGroup creates a new group with the given name and parent group.
 //
 // The root group must be created with the name "" and parent set to nil; this is the only case
 // where a nil parent or empty name is allowed.
@@ -113,7 +116,7 @@ func NewGroup(name string, parent *Group) (*Group, error) {
 		path = parent.Path + GroupSeparator + path
 	}
 
-	hash := md5.Sum([]byte(path))
+	hash := md5.Sum([]byte(path)) //nolint:gosec
 	id := hex.EncodeToString(hash[:])
 
 	return &Group{
@@ -133,13 +136,13 @@ func (g *Group) Group(name string) (*Group, error) {
 	defer g.groupMutex.Unlock()
 	group, ok := g.Groups[name]
 	if !ok {
-		group, err := NewGroup(name, g)
+		var err error
+		group, err = NewGroup(name, g)
 		if err != nil {
 			return nil, err
 		}
 		g.Groups[name] = group
 		g.OrderedGroups = append(g.OrderedGroups, group)
-		return group, nil
 	}
 	return group, nil
 }
@@ -151,13 +154,13 @@ func (g *Group) Check(name string) (*Check, error) {
 	defer g.checkMutex.Unlock()
 	check, ok := g.Checks[name]
 	if !ok {
-		check, err := NewCheck(name, g)
+		var err error
+		check, err = NewCheck(name, g)
 		if err != nil {
 			return nil, err
 		}
 		g.Checks[name] = check
 		g.OrderedChecks = append(g.OrderedChecks, check)
-		return check, nil
 	}
 	return check, nil
 }
@@ -187,14 +190,14 @@ type Check struct {
 	Fails  int64 `json:"fails"`
 }
 
-// Creates a new check with the given name and parent group. The group may not be nil.
+// NewCheck creates a new check with the given name and parent group. The group may not be nil.
 func NewCheck(name string, group *Group) (*Check, error) {
 	if strings.Contains(name, GroupSeparator) {
 		return nil, ErrNameContainsGroupSeparator
 	}
 
 	path := group.Path + GroupSeparator + name
-	hash := md5.Sum([]byte(path))
+	hash := md5.Sum([]byte(path)) //nolint:gosec
 	id := hex.EncodeToString(hash[:])
 
 	return &Check{
