@@ -8,12 +8,13 @@ import (
 	"net"
 	"strconv"
 	"strings"
+	"time"
 
+	"github.com/sirupsen/logrus"
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/metrics"
 
 	protov1 "github.com/golang/protobuf/proto" //nolint:staticcheck,nolintlint // this is the old v1 version
-	"github.com/sirupsen/logrus"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/metadata"
@@ -27,15 +28,18 @@ import (
 	"google.golang.org/protobuf/types/dynamicpb"
 )
 
-// Request represents a gRPC request.
-type Request struct {
+// InvokeRequest represents a unary gRPC request.
+type InvokeRequest struct {
+	Method           string
 	MethodDescriptor protoreflect.MethodDescriptor
+	Timeout          time.Duration
 	TagsAndMeta      *metrics.TagsAndMeta
 	Message          []byte
+	Metadata         metadata.MD
 }
 
-// Response represents a gRPC response.
-type Response struct {
+// InvokeResponse represents a gRPC response.
+type InvokeResponse struct {
 	Message  interface{}
 	Error    interface{}
 	Headers  map[string][]string
@@ -43,6 +47,15 @@ type Response struct {
 	Status   codes.Code
 }
 
+// StreamRequest represents a gRPC stream request.
+type StreamRequest struct {
+	Method           string
+	MethodDescriptor protoreflect.MethodDescriptor
+	Timeout          time.Duration
+	TagsAndMeta      *metrics.TagsAndMeta
+	Metadata         metadata.MD
+}
+
 type clientConnCloser interface {
 	grpc.ClientConnInterface
 	Close() error
@@ -89,14 +102,13 @@ func (c *Conn) Reflect(ctx context.Context) (*descriptorpb.FileDescriptorSet, er
 // Invoke executes a unary gRPC request.
 func (c *Conn) Invoke(
 	ctx context.Context,
-	url string,
-	md metadata.MD,
-	req Request,
+	req InvokeRequest,
 	opts ...grpc.CallOption,
-) (*Response, error) {
-	if url == "" {
+) (*InvokeResponse, error) {
+	if req.Method == "" {
 		return nil, fmt.Errorf("url is required")
 	}
+
 	if req.MethodDescriptor == nil {
 		return nil, fmt.Errorf("request method descriptor is required")
 	}
@@ -104,7 +116,13 @@ func (c *Conn) Invoke(
 		return nil, fmt.Errorf("request message is required")
 	}
 
-	ctx = metadata.NewOutgoingContext(ctx, md)
+	if req.Timeout != time.Duration(0) {
+		var cancel context.CancelFunc
+		ctx, cancel = context.WithTimeout(ctx, req.Timeout)
+		defer cancel()
+	}
+
+	ctx = metadata.NewOutgoingContext(ctx, req.Metadata)
 
 	reqdm := dynamicpb.NewMessage(req.MethodDescriptor.Input())
 	if err := protojson.Unmarshal(req.Message, reqdm); err != nil {
@@ -120,9 +138,9 @@ func (c *Conn) Invoke(
 	copts = append(copts, opts...)
 	copts = append(copts, grpc.Header(&header), grpc.Trailer(&trailer))
 
-	err := c.raw.Invoke(ctx, url, reqdm, resp, copts...)
+	err := c.raw.Invoke(ctx, req.Method, reqdm, resp, copts...)
 
-	response := Response{
+	response := InvokeResponse{
 		Headers:  header,
 		Trailers: trailer,
 	}
@@ -146,28 +164,42 @@ func (c *Conn) Invoke(
 	}
 
 	if resp != nil {
-		// (rogchap) there is a lot of marshaling/unmarshaling here, but if we just pass the dynamic message
-		// the default Marshaller would be used, which would strip any zero/default values from the JSON.
-		// eg. given this message:
-		// message Point {
-		//    double x = 1;
-		// 	  double y = 2;
-		// 	  double z = 3;
-		// }
-		// and a value like this:
-		// msg := Point{X: 6, Y: 4, Z: 0}
-		// would result in JSON output:
-		// {"x":6,"y":4}
-		// rather than the desired:
-		// {"x":6,"y":4,"z":0}
-		raw, _ := marshaler.Marshal(resp)
-		var msg interface{}
-		_ = json.Unmarshal(raw, &msg)
+		msg, err := convert(marshaler, resp)
+		if err != nil {
+			return nil, fmt.Errorf("unable to convert response object to JSON: %w", err)
+		}
+
 		response.Message = msg
 	}
 	return &response, nil
 }
 
+// NewStream creates a new gRPC stream.
+func (c *Conn) NewStream(
+	ctx context.Context,
+	req StreamRequest,
+	opts ...grpc.CallOption,
+) (*Stream, error) {
+	ctx = metadata.NewOutgoingContext(ctx, req.Metadata)
+
+	ctx = withRPCState(ctx, &rpcState{tagsAndMeta: req.TagsAndMeta})
+
+	stream, err := c.raw.NewStream(ctx, &grpc.StreamDesc{
+		StreamName:    string(req.MethodDescriptor.Name()),
+		ServerStreams: req.MethodDescriptor.IsStreamingServer(),
+		ClientStreams: req.MethodDescriptor.IsStreamingClient(),
+	}, req.Method, opts...)
+	if err != nil {
+		return nil, err
+	}
+
+	return &Stream{
+		raw:              stream,
+		method:           req.Method,
+		methodDescriptor: req.MethodDescriptor,
+	}, nil
+}
+
 // Close closes the underhood connection.
 func (c *Conn) Close() error {
 	return c.raw.Close()
